@@ -4,7 +4,7 @@ rbind.incidence2 <- function (..., deparse.level = 1) {
     first <- dat[[1L]]
     compatible <- sapply(dat, inherits, "data.frame")
     if (!all(compatible))
-        stop("Incompatible inputs")
+        .stop_argument("Incompatible inputs")
     dat <- lapply(dat, as.data.frame)
     out <- do.call(rbind, dat)
     .incidence_reconstruct(out, first)
